@@ -115,6 +115,9 @@ void empathy_individual_can_audio_video_call (FolksIndividual *individual,
     gboolean *can_video_call,
     EmpathyContact **out_contact);
 
+gboolean empathy_client_types_contains_mobile_device (
+    const GStrv types);
+
 FolksIndividual * empathy_create_individual_from_tp_contact (
     TpContact *contact);
 
