@@ -986,9 +986,9 @@ chat_window_update_chat_tab_full (EmpathyChat *chat,
       const gchar * const *types;
 
       types = empathy_contact_get_client_types (remote_contact);
-      if (types != NULL && !tp_strdiff (types[0], "phone"))
+      if (empathy_client_types_contains_mobile_device ((GStrv) types))
         {
-          /* I'm on a phone ! */
+          /* I'm on a mobile device ! */
           gchar *tmp = name;
 
           name = g_strdup_printf ("☎ %s", name);
@@ -1574,13 +1574,13 @@ chat_window_show_or_update_notification (EmpathyChatWindow *self,
       const gchar *category = empathy_chat_is_room (chat)
         ? EMPATHY_NOTIFICATION_CATEGORY_MENTIONED
         : EMPATHY_NOTIFICATION_CATEGORY_CHAT;
-      notification = notify_notification_new (header, escaped, NULL);
+
+      notification = empathy_notify_manager_create_notification (header,
+          escaped, NULL);
 
       if (self->priv->notification == NULL)
         self->priv->notification = notification;
 
-      notify_notification_set_timeout (notification, NOTIFY_EXPIRES_DEFAULT);
-
       tp_g_signal_connect_object (notification, "closed",
             G_CALLBACK (chat_window_notification_closed_cb), self, 0);
 
